@@ -18,9 +18,11 @@ import easytorch.data.datautils as _du
 import easytorch.utils as _etutils
 from easytorch.utils.logger import *
 
+_LOG_FREQ = 200
+
 
 def _job(total, func, i, f):
-    print(f"Working on: [ {i}/{total} ]", end='\r')
+    print(f"Working on: [ {i}/{total} ]", end='\n' if i % _LOG_FREQ == 0 else '\r')
     return func(f)
 
 
@@ -65,7 +67,7 @@ def _et_data_job_func(mode, file, dataspec, args, dataset_cls):
 
 def _et_data_job(mode, arg, dspec, cls, total, func, verbose, i, file):
     if verbose:
-        print(f"Working on: [ {i} / {total} ]", end='\r')
+        print(f"Working on: [ {i} / {total} ]", end='\n' if i % _LOG_FREQ == 0 else '\r')
     return func(mode, file, dspec, arg, cls)
 
 
